==> haskell-io-streams-haproxy-1.0.1.0-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: io-streams-haproxy
version: 1.0.1.0
id: io-streams-haproxy-1.0.1.0-CqoNSl2grOGHVfr293Jmtx
key: io-streams-haproxy-1.0.1.0-CqoNSl2grOGHVfr293Jmtx
license: BSD-3-Clause
copyright: (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer: greg@gregorycollins.net
author: Gregory Collins
homepage: http://snapframework.com/
synopsis: HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.
category: Network, IO-Streams
abi: e1569144e45873a4db8a5a1bd985b187
exposed: True
exposed-modules:
    System.IO.Streams.Network.HAProxy
hidden-modules: System.IO.Streams.Network.Internal.Address
import-dirs: /usr/lib/ghc-8.6.5/site-local/io-streams-haproxy-1.0.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/io-streams-haproxy-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/io-streams-haproxy-1.0.1.0
hs-libraries: HSio-streams-haproxy-1.0.1.0-CqoNSl2grOGHVfr293Jmtx
depends:
    attoparsec-0.13.2.2-EdUct2wsQri8X0bjC24wTV base-4.12.0.0
    bytestring-0.10.8.2 io-streams-1.5.1.0-Kwg7k2tBL6yEFMO0cqCZzB
    network-2.8.0.0-KwUidTBebCCJ8Fjkxwovi transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock
haddock-html: /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-io-streams-haproxy-1.0.1.0-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: io-streams-haproxy
version: 1.0.1.0
id: io-streams-haproxy-1.0.1.0-BxHjSjMmpTo5i6x3mxnzvm
key: io-streams-haproxy-1.0.1.0-BxHjSjMmpTo5i6x3mxnzvm
license: BSD-3-Clause
copyright: (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer: greg@gregorycollins.net
author: Gregory Collins
homepage: http://snapframework.com/
synopsis: HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.
category: Network, IO-Streams
abi: 01dfbd7cc35a732cec3d1c59fd20cee0
exposed: True
exposed-modules:
    System.IO.Streams.Network.HAProxy
hidden-modules: System.IO.Streams.Network.Internal.Address
import-dirs: /usr/lib/ghc-8.6.5/site-local/io-streams-haproxy-1.0.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/io-streams-haproxy-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/io-streams-haproxy-1.0.1.0
hs-libraries: HSio-streams-haproxy-1.0.1.0-BxHjSjMmpTo5i6x3mxnzvm
depends:
    attoparsec-0.13.2.2-EdUct2wsQri8X0bjC24wTV base-4.12.0.0
    bytestring-0.10.8.2 io-streams-1.5.1.0-7fREBcZFGKy8pwYLXQXocc
    network-2.8.0.0-FZwMvc7MoUJBpGGHu2O13h transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock
haddock-html: /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
